==> hibernate-search-mapper-pojo-base-6.2.4.Final-sources.jar: org/hibernate/search/mapper/pojo/bridge/mapping/programmatic/identifiertovalue/impl/ValueBindingContextToIdentifierBindingContextAdapter.java <==
/*
 * Hibernate Search, full-text search for your domain model
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
package org.hibernate.search.mapper.pojo.bridge.mapping.programmatic.identifiertovalue.impl;

import java.util.Optional;

import org.hibernate.search.engine.environment.bean.BeanHolder;
import org.hibernate.search.engine.environment.bean.BeanResolver;
import org.hibernate.search.mapper.pojo.bridge.IdentifierBridge;
import org.hibernate.search.mapper.pojo.bridge.binding.IdentifierBindingContext;
import org.hibernate.search.mapper.pojo.bridge.binding.ValueBindingContext;
import org.hibernate.search.mapper.pojo.model.PojoModelValue;

final class ValueBindingContextToIdentifierBindingContextAdapter<I> implements IdentifierBindingContext<I> {
	private final ValueBindingContext<I> delegate;

	public ValueBindingContextToIdentifierBindingContextAdapter(ValueBindingContext<I> delegate) {
		this.delegate = delegate;
	}

	@Override
	public <I2> void bridge(Class<I2> expectedIdentifierType, IdentifierBridge<I2> bridge) {
		delegate.bridge( expectedIdentifierType, new IdentifierBridgeToValueBridgeAdapter<>( bridge ),
				delegate.typeFactory().asString() );
	}

	@Override
	public <I2> void bridge(Class<I2> expectedIdentifierType, BeanHolder<? extends IdentifierBridge<I2>> bridgeHolder) {
		delegate.bridge( expectedIdentifierType,
				BeanHolder.of( new IdentifierBridgeToValueBridgeAdapter<>( bridgeHolder.get() ) )
						.withDependencyAutoClosing( bridgeHolder ),
				delegate.typeFactory().asString() );
	}

	@Override
	public PojoModelValue<I> bridgedElement() {
		return delegate.bridgedElement();
	}

	@Override
	public Object param(String name) {
		return delegate.param( name );
	}

	@Override
	public Optional<Object> paramOptional(String name) {
		return delegate.paramOptional( name );
	}

	@Override
	public BeanResolver beanResolver() {
		return delegate.beanResolver();
	}
}

==> hibernate-search-mapper-pojo-base-7.2.2.Final-sources.jar: org/hibernate/search/mapper/pojo/bridge/mapping/programmatic/identifiertovalue/impl/ValueBindingContextToIdentifierBindingContextAdapter.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 * Copyright Red Hat Inc. and Hibernate Authors
 */
package org.hibernate.search.mapper.pojo.bridge.mapping.programmatic.identifiertovalue.impl;

import org.hibernate.search.engine.environment.bean.BeanHolder;
import org.hibernate.search.engine.environment.bean.BeanResolver;
import org.hibernate.search.engine.search.common.NamedValues;
import org.hibernate.search.mapper.pojo.bridge.IdentifierBridge;
import org.hibernate.search.mapper.pojo.bridge.binding.IdentifierBindingContext;
import org.hibernate.search.mapper.pojo.bridge.binding.ValueBindingContext;
import org.hibernate.search.mapper.pojo.model.PojoModelValue;

final class ValueBindingContextToIdentifierBindingContextAdapter<I> implements IdentifierBindingContext<I> {
	private final ValueBindingContext<I> delegate;

	public ValueBindingContextToIdentifierBindingContextAdapter(ValueBindingContext<I> delegate) {
		this.delegate = delegate;
	}

	@Override
	public <I2> void bridge(Class<I2> expectedIdentifierType, IdentifierBridge<I2> bridge) {
		delegate.bridge( expectedIdentifierType, new IdentifierBridgeToValueBridgeAdapter<>( bridge ),
				delegate.typeFactory().asString() );
	}

	@Override
	public <I2> void bridge(Class<I2> expectedIdentifierType, BeanHolder<? extends IdentifierBridge<I2>> bridgeHolder) {
		delegate.bridge( expectedIdentifierType,
				BeanHolder.of( new IdentifierBridgeToValueBridgeAdapter<>( bridgeHolder.get() ) )
						.withDependencyAutoClosing( bridgeHolder ),
				delegate.typeFactory().asString() );
	}

	@Override
	public PojoModelValue<I> bridgedElement() {
		return delegate.bridgedElement();
	}

	@Override
	public NamedValues params() {
		return delegate.params();
	}

	@Override
	public BeanResolver beanResolver() {
		return delegate.beanResolver();
	}
}
